Function claim_pending_deposit

pub fn claim_pending_deposit<T: Config>(asset_id: AssetId, beneficiary: H160)
Claim a pending deposit for a given asset and beneficiary. Callable by any signed origin (permissionless). Tokens are minted to the beneficiary, not the caller. Requires the asset to be active (unfrozen).

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::claim_pending_deposit.